==> aom-docs-3.8.0-2-aarch64.pkg.tar.xz: usr/share/doc/aom/structAV1__COMP.js <==
var structAV1__COMP =
[
    [ "ppi", "structAV1__COMP.html#aa61580d294015592b73d58ca79e7f09a", null ],
    [ "enc_quant_dequant_params", "structAV1__COMP.html#ae0e9447a3719724582351cd5e5d4ee72", null ],
    [ "td", "structAV1__COMP.html#ad889729b799aade846fe7a2e5d27dea8", null ],
    [ "counts", "structAV1__COMP.html#a7305c275e154639e8e70a7cfefcce324", null ],
    [ "mbmi_ext_info", "structAV1__COMP.html#aa1334c97aadc350e172b65908170bbea", null ],
    [ "coeff_buffer_base", "structAV1__COMP.html#af9ac137b7403a03b8a47f1c681230c43", null ],
    [ "coeff_buffer_pool", "structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9", null ],
    [ "common", "structAV1__COMP.html#a6c5ff3b8df382c108abbb290502d6242", null ],
    [ "oxcf", "structAV1__COMP.html#a683b6b6df2109e6301e61b07678cfa12", null ],
    [ "optimize_seg_arr", "structAV1__COMP.html#a391735210b755ea3e9de4777dd10965b", null ],
    [ "source", "structAV1__COMP.html#af506182c1bce3b944fcc72cd723e1bc7", null ],
    [ "last_source", "structAV1__COMP.html#a8a6dffc3949931c07ab86f18539c3ab8", null ],
    [ "unscaled_source", "structAV1__COMP.html#a0ee379148254c9d67fcf13ab0038bfa4", null ],
    [ "scaled_source", "structAV1__COMP.html#adbb26cb8b6396b47305a33841c1af997", null ],
    [ "unscaled_last_source", "structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91", null ],
    [ "scaled_last_source", "structAV1__COMP.html#aedbfd57eeefc819431091d2be25cab11", null ],
    [ "unfiltered_source", "structAV1__COMP.html#a91905e3eeee006840918bd3aaf93bab7", null ],
    [ "orig_source", "structAV1__COMP.html#ac534821577b4f8243259fe38fb948d35", null ],
    [ "skip_tpl_setup_stats", "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb", null ],
    [ "tpl_rdmult_scaling_factors", "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59", null ],
    [ "tf_ctx", "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846", null ],
    [ "cdef_search_ctx", "structAV1__COMP.html#a6f20ccca66ccc28bea06f8452311a2f7", null ],
    [ "force_intpel_info", "structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb", null ],
    [ "scaled_ref_buf", "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc", null ],
    [ "last_show_frame_buf", "structAV1__COMP.html#a9c4957c740b2c95513d7af9ed2999211", null ],
    [ "refresh_frame", "structAV1__COMP.html#a7e0661a8322b19a27c9969d2898ed858", null ],
    [ "rt_reduce_num_ref_buffers", "structAV1__COMP.html#a7c68dc43bf3c85698d913e3c9968b40a", null ],
    [ "ext_flags", "structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc", null ],
    [ "last_frame_uf", "structAV1__COMP.html#ae0e804c9201665f126ceb0c693dd1d25", null ],
    [ "trial_frame_rst", "structAV1__COMP.html#ad780d3cebefa7f76b212c0cb8de3f140", null ],
    [ "ambient_err", "structAV1__COMP.html#a299a82348f6f2e0b1cf7d90940a8f371", null ],
    [ "rd", "structAV1__COMP.html#a3bd63a7c3fce5555319fc797beae8849", null ],
    [ "coding_context", "structAV1__COMP.html#a4fc82f94416481dd23593999de64e369", null ],
    [ "gm_info", "structAV1__COMP.html#a58ea35e30c39019ec39bca542d4d7d64", null ],
    [ "winner_mode_params", "structAV1__COMP.html#a444d81f3fcfdd6a4205aa4318b7cafca", null ],
    [ "time_stamps", "structAV1__COMP.html#ac2d5ab9e6b97e486238656a0fbf266d4", null ],
    [ "rc", "structAV1__COMP.html#a25f6a4b1abb3966d77be127dcd8b6476", null ],
    [ "framerate", "structAV1__COMP.html#acafbb7d6233ce98630ee3d3da4e39c0b", null ],
    [ "ref_frame_flags", "structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece", null ],
    [ "speed", "structAV1__COMP.html#ad27d351fdb5c7202a8d362d79d030c58", null ],
    [ "sf", "structAV1__COMP.html#a37618681daa2a234bbfb424ce6d22f5b", null ],
    [ "mv_search_params", "structAV1__COMP.html#a4ac2ac3d57f1620126ab34d1f19f2943", null ],
    [ "all_one_sided_refs", "structAV1__COMP.html#a8172b1a8dc8d210fa745138938874fb7", null ],
    [ "enc_seg", "structAV1__COMP.html#a4a7cab775d531af4ba9f1eaeccd34a58", null ],
    [ "cyclic_refresh", "structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162", null ],
    [ "active_map", "structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f", null ],
    [ "gf_frame_index", "structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65", null ],
    [ "droppable", "structAV1__COMP.html#a9c014587b95805c0d3d3196b3108122e", null ],
    [ "frame_info", "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415", null ],
    [ "frame_index_set", "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f", null ],
    [ "initial_dimensions", "structAV1__COMP.html#a21089e9068a35e00fd998812430b5fa5", null ],
    [ "initial_mbs", "structAV1__COMP.html#ae99e19b47623d78945a150a2bb590e0e", null ],
    [ "resize_pending_params", "structAV1__COMP.html#ad90676c429c93f4834e02fd8da6f5b2f", null ],
    [ "tile_data", "structAV1__COMP.html#ab7cbfe13c6ccdfca2418b4a6ce950bfe", null ],
    [ "allocated_tiles", "structAV1__COMP.html#af6095ff5110e00d17cb6f5897e17c8c2", null ],
    [ "token_info", "structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c", null ],
    [ "vaq_refresh", "structAV1__COMP.html#a066a671f4995bbcf08b2110105391195", null ],
    [ "vbp_info", "structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1", null ],
    [ "num_frame_recode", "structAV1__COMP.html#a7c2391b88acf55f27fee48eee1d9deba", null ],
    [ "frame_new_probs", "structAV1__COMP.html#af1ec2b7dd9f111bc7a4f38bf8c254e61", null ],
    [ "do_update_frame_probs_txtype", "structAV1__COMP.html#a70a2523a80b95533cb00052e485cdc9a", null ],
    [ "do_update_frame_probs_obmc", "structAV1__COMP.html#a04e419d46527a4ffe5bd7151570a7c03", null ],
    [ "do_update_frame_probs_warp", "structAV1__COMP.html#a032b8d30bbb0868fb90c519400d8d388", null ],
    [ "do_update_frame_probs_interpfilter", "structAV1__COMP.html#a4f0c3420fc582c1e40452334689eb127", null ],
    [ "new_framerate", "structAV1__COMP.html#aa3403fc90f89d25b1b18ed11e14384c1", null ],
    [ "do_update_vbr_bits_off_target_fast", "structAV1__COMP.html#ae07d96e30e4ebfacc674f9fe88cc687e", null ],
    [ "mt_info", "structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb", null ],
    [ "existing_fb_idx_to_show", "structAV1__COMP.html#a8e29879e2541a075abb94510dc698007", null ],
    [ "intrabc_used", "structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f", null ],
    [ "prune_ref_frame_mask", "structAV1__COMP.html#a7ee7e00e3423b19eac935c9a27c14a8d", null ],
    [ "lr_ctxt", "structAV1__COMP.html#a6dc37728067978a7637f76c6b7c41979", null ],
    [ "pick_lr_ctxt", "structAV1__COMP.html#aa2c5ad94c8bc0d7da5a4354bbe68301b", null ],
    [ "film_grain_table", "structAV1__COMP.html#a2a451884130382a33642dd88e7e4a426", null ],
    [ "denoise_and_model", "structAV1__COMP.html#a0605ca1d559b9566e13aa8d2d2e55284", null ],
    [ "interp_search_flags", "structAV1__COMP.html#abdbb43940e22262999e72bccf44fb1a2", null ],
    [ "use_screen_content_tools", "structAV1__COMP.html#a4ca11c36b5bab99d6240752ff37a89a3", null ],
    [ "is_screen_content_type", "structAV1__COMP.html#ab86c618addbf983a08da80ae806d03f3", null ],
    [ "frame_header_count", "structAV1__COMP.html#a9aea0ecc72af0b304c33dae392a884f6", null ],
    [ "deltaq_used", "structAV1__COMP.html#a26de3eb8d7f7d75083c364f754507562", null ],
    [ "ref_frame_dist_info", "structAV1__COMP.html#ae17f8b5096955a0bb3a553c719c362e3", null ],
    [ "ssim_rdmult_scaling_factors", "structAV1__COMP.html#a3b3aa4af7d870ee595dbe487c37d3950", null ],
    [ "svc", "structAV1__COMP.html#af8128359d98cbd69def126adb45965ef", null ],
    [ "compressor_stage", "structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421", null ],
    [ "last_frame_type", "structAV1__COMP.html#a0ac239b9892a1799eda25582b402430e", null ],
    [ "num_tg", "structAV1__COMP.html#a3f3c93cc1e7ce42de06a8aae22397fcf", null ],
    [ "superres_mode", "structAV1__COMP.html#a9d47cd6cfb938137c22514c510a946b5", null ],
    [ "firstpass_data", "structAV1__COMP.html#acac975b1b40d779f5475ea38b852a9f6", null ],
    [ "noise_estimate", "structAV1__COMP.html#afb2b64c6890885dbc8ebf1b1e49941e0", null ],
    [ "consec_zero_mv", "structAV1__COMP.html#a044d3dfed6b8921cd7d74dee128d987e", null ],
    [ "consec_zero_mv_alloc_size", "structAV1__COMP.html#a5d82be59e7badc649655a7f281b017c2", null ],
    [ "fp_block_size", "structAV1__COMP.html#ad2c0908b11b789a2df0a90e563a433ea", null ],
    [ "sb_counter", "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0", null ],
    [ "available_bs_size", "structAV1__COMP.html#a30c0d235c498e05247be568b93b98081", null ],
    [ "ext_part_controller", "structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86", null ],
    [ "mv_stats", "structAV1__COMP.html#aefe4d284d22f10945fe1c18cb2a095a4", null ],
    [ "ref_refresh_index", "structAV1__COMP.html#a2a58033f237baf3237ae7859e0397ad3", null ],
    [ "refresh_idx_available", "structAV1__COMP.html#a284dd9a2a0f4d09930197bc78d5c1209", null ],
    [ "ref_idx_to_skip", "structAV1__COMP.html#ac4f9451eed486d0cfb177321491e3a31", null ],
    [ "do_frame_data_update", "structAV1__COMP.html#a6e6ceda86270005d35ace1b04ec593bf", null ],
    [ "mb_weber_stats", "structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9", null ],
    [ "prep_rate_estimates", "structAV1__COMP.html#ae361e3256289fc9e62328dab440e7691", null ],
    [ "ext_rate_distribution", "structAV1__COMP.html#a01c7acc7ea64292b9563d4b8dc7d8fb3", null ],
    [ "ext_rate_scale", "structAV1__COMP.html#ae69f2f43c6b433ab69619b46f8182127", null ],
    [ "weber_bsize", "structAV1__COMP.html#ab96a678fa569c136c2ed087b68a2d401", null ],
    [ "norm_wiener_variance", "structAV1__COMP.html#aa7f83fb36f70ef378393873e41a26f7e", null ],
    [ "mb_delta_q", "structAV1__COMP.html#a063d56623dcab7e26974036303ef012e", null ],
    [ "is_dropped_frame", "structAV1__COMP.html#ad7a2fbeb7e11ff525044f82b73d1f56b", null ],
    [ "twopass_frame", "structAV1__COMP.html#afc1e293e4ae3b459e8f8d785540f6257", null ],
    [ "third_pass_ctx", "structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27", null ],
    [ "second_pass_log_stream", "structAV1__COMP.html#a3a5748228c0070093a482972587f43e5", null ],
    [ "src_sad_blk_64x64", "structAV1__COMP.html#aa6e74802d8f8aecfaa32dce27d0f0c67", null ],
    [ "rec_sse", "structAV1__COMP.html#aecdcb0ad8bfc529a749c41fc82ca5f8e", null ],
    [ "use_ducky_encode", "structAV1__COMP.html#ad36e29542fdcc0b7c2c67e142381f252", null ],
    [ "ducky_encode_info", "structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7", null ],
    [ "frames_since_last_update", "structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b", null ],
    [ "zeromv_skip_thresh_exit_part", "structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b", null ],
    [ "image_pyramid_levels", "structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e", null ],
    [ "palette_pixel_num", "structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6", null ]
];

==> aom-docs-3.8.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/structAV1__COMP.js <==
var structAV1__COMP =
[
    [ "ppi", "structAV1__COMP.html#aa61580d294015592b73d58ca79e7f09a", null ],
    [ "enc_quant_dequant_params", "structAV1__COMP.html#ae0e9447a3719724582351cd5e5d4ee72", null ],
    [ "td", "structAV1__COMP.html#ad889729b799aade846fe7a2e5d27dea8", null ],
    [ "counts", "structAV1__COMP.html#a7305c275e154639e8e70a7cfefcce324", null ],
    [ "mbmi_ext_info", "structAV1__COMP.html#aa1334c97aadc350e172b65908170bbea", null ],
    [ "coeff_buffer_base", "structAV1__COMP.html#af9ac137b7403a03b8a47f1c681230c43", null ],
    [ "coeff_buffer_pool", "structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9", null ],
    [ "common", "structAV1__COMP.html#a6c5ff3b8df382c108abbb290502d6242", null ],
    [ "oxcf", "structAV1__COMP.html#a683b6b6df2109e6301e61b07678cfa12", null ],
    [ "optimize_seg_arr", "structAV1__COMP.html#a391735210b755ea3e9de4777dd10965b", null ],
    [ "source", "structAV1__COMP.html#af506182c1bce3b944fcc72cd723e1bc7", null ],
    [ "last_source", "structAV1__COMP.html#a8a6dffc3949931c07ab86f18539c3ab8", null ],
    [ "unscaled_source", "structAV1__COMP.html#a0ee379148254c9d67fcf13ab0038bfa4", null ],
    [ "scaled_source", "structAV1__COMP.html#adbb26cb8b6396b47305a33841c1af997", null ],
    [ "unscaled_last_source", "structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91", null ],
    [ "scaled_last_source", "structAV1__COMP.html#aedbfd57eeefc819431091d2be25cab11", null ],
    [ "unfiltered_source", "structAV1__COMP.html#a91905e3eeee006840918bd3aaf93bab7", null ],
    [ "orig_source", "structAV1__COMP.html#ac534821577b4f8243259fe38fb948d35", null ],
    [ "skip_tpl_setup_stats", "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb", null ],
    [ "tpl_rdmult_scaling_factors", "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59", null ],
    [ "tf_ctx", "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846", null ],
    [ "cdef_search_ctx", "structAV1__COMP.html#a6f20ccca66ccc28bea06f8452311a2f7", null ],
    [ "force_intpel_info", "structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb", null ],
    [ "scaled_ref_buf", "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc", null ],
    [ "last_show_frame_buf", "structAV1__COMP.html#a9c4957c740b2c95513d7af9ed2999211", null ],
    [ "refresh_frame", "structAV1__COMP.html#a7e0661a8322b19a27c9969d2898ed858", null ],
    [ "rt_reduce_num_ref_buffers", "structAV1__COMP.html#a7c68dc43bf3c85698d913e3c9968b40a", null ],
    [ "ext_flags", "structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc", null ],
    [ "last_frame_uf", "structAV1__COMP.html#ae0e804c9201665f126ceb0c693dd1d25", null ],
    [ "trial_frame_rst", "structAV1__COMP.html#ad780d3cebefa7f76b212c0cb8de3f140", null ],
    [ "ambient_err", "structAV1__COMP.html#a299a82348f6f2e0b1cf7d90940a8f371", null ],
    [ "rd", "structAV1__COMP.html#a3bd63a7c3fce5555319fc797beae8849", null ],
    [ "coding_context", "structAV1__COMP.html#a4fc82f94416481dd23593999de64e369", null ],
    [ "gm_info", "structAV1__COMP.html#a58ea35e30c39019ec39bca542d4d7d64", null ],
    [ "winner_mode_params", "structAV1__COMP.html#a444d81f3fcfdd6a4205aa4318b7cafca", null ],
    [ "time_stamps", "structAV1__COMP.html#ac2d5ab9e6b97e486238656a0fbf266d4", null ],
    [ "rc", "structAV1__COMP.html#a25f6a4b1abb3966d77be127dcd8b6476", null ],
    [ "framerate", "structAV1__COMP.html#acafbb7d6233ce98630ee3d3da4e39c0b", null ],
    [ "ref_frame_flags", "structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece", null ],
    [ "speed", "structAV1__COMP.html#ad27d351fdb5c7202a8d362d79d030c58", null ],
    [ "sf", "structAV1__COMP.html#a37618681daa2a234bbfb424ce6d22f5b", null ],
    [ "mv_search_params", "structAV1__COMP.html#a4ac2ac3d57f1620126ab34d1f19f2943", null ],
    [ "all_one_sided_refs", "structAV1__COMP.html#a8172b1a8dc8d210fa745138938874fb7", null ],
    [ "enc_seg", "structAV1__COMP.html#a4a7cab775d531af4ba9f1eaeccd34a58", null ],
    [ "cyclic_refresh", "structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162", null ],
    [ "active_map", "structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f", null ],
    [ "gf_frame_index", "structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65", null ],
    [ "droppable", "structAV1__COMP.html#a9c014587b95805c0d3d3196b3108122e", null ],
    [ "frame_info", "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415", null ],
    [ "frame_index_set", "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f", null ],
    [ "initial_dimensions", "structAV1__COMP.html#a21089e9068a35e00fd998812430b5fa5", null ],
    [ "initial_mbs", "structAV1__COMP.html#ae99e19b47623d78945a150a2bb590e0e", null ],
    [ "frame_size_related_setup_done", "structAV1__COMP.html#a2728d8d8f677f3a2956a2833d404d2b3", null ],
    [ "last_coded_width", "structAV1__COMP.html#ab777a8c3ab7645c3206edb51cd4d5eeb", null ],
    [ "last_coded_height", "structAV1__COMP.html#a9987c30f368252cd197dbbfed940c469", null ],
    [ "resize_pending_params", "structAV1__COMP.html#ad90676c429c93f4834e02fd8da6f5b2f", null ],
    [ "tile_data", "structAV1__COMP.html#ab7cbfe13c6ccdfca2418b4a6ce950bfe", null ],
    [ "allocated_tiles", "structAV1__COMP.html#af6095ff5110e00d17cb6f5897e17c8c2", null ],
    [ "token_info", "structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c", null ],
    [ "vaq_refresh", "structAV1__COMP.html#a066a671f4995bbcf08b2110105391195", null ],
    [ "vbp_info", "structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1", null ],
    [ "num_frame_recode", "structAV1__COMP.html#a7c2391b88acf55f27fee48eee1d9deba", null ],
    [ "frame_new_probs", "structAV1__COMP.html#af1ec2b7dd9f111bc7a4f38bf8c254e61", null ],
    [ "do_update_frame_probs_txtype", "structAV1__COMP.html#a70a2523a80b95533cb00052e485cdc9a", null ],
    [ "do_update_frame_probs_obmc", "structAV1__COMP.html#a04e419d46527a4ffe5bd7151570a7c03", null ],
    [ "do_update_frame_probs_warp", "structAV1__COMP.html#a032b8d30bbb0868fb90c519400d8d388", null ],
    [ "do_update_frame_probs_interpfilter", "structAV1__COMP.html#a4f0c3420fc582c1e40452334689eb127", null ],
    [ "new_framerate", "structAV1__COMP.html#aa3403fc90f89d25b1b18ed11e14384c1", null ],
    [ "do_update_vbr_bits_off_target_fast", "structAV1__COMP.html#ae07d96e30e4ebfacc674f9fe88cc687e", null ],
    [ "mt_info", "structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb", null ],
    [ "existing_fb_idx_to_show", "structAV1__COMP.html#a8e29879e2541a075abb94510dc698007", null ],
    [ "intrabc_used", "structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f", null ],
    [ "prune_ref_frame_mask", "structAV1__COMP.html#a7ee7e00e3423b19eac935c9a27c14a8d", null ],
    [ "lr_ctxt", "structAV1__COMP.html#a6dc37728067978a7637f76c6b7c41979", null ],
    [ "pick_lr_ctxt", "structAV1__COMP.html#aa2c5ad94c8bc0d7da5a4354bbe68301b", null ],
    [ "film_grain_table", "structAV1__COMP.html#a2a451884130382a33642dd88e7e4a426", null ],
    [ "denoise_and_model", "structAV1__COMP.html#a0605ca1d559b9566e13aa8d2d2e55284", null ],
    [ "interp_search_flags", "structAV1__COMP.html#abdbb43940e22262999e72bccf44fb1a2", null ],
    [ "use_screen_content_tools", "structAV1__COMP.html#a4ca11c36b5bab99d6240752ff37a89a3", null ],
    [ "is_screen_content_type", "structAV1__COMP.html#ab86c618addbf983a08da80ae806d03f3", null ],
    [ "frame_header_count", "structAV1__COMP.html#a9aea0ecc72af0b304c33dae392a884f6", null ],
    [ "deltaq_used", "structAV1__COMP.html#a26de3eb8d7f7d75083c364f754507562", null ],
    [ "ref_frame_dist_info", "structAV1__COMP.html#ae17f8b5096955a0bb3a553c719c362e3", null ],
    [ "ssim_rdmult_scaling_factors", "structAV1__COMP.html#a3b3aa4af7d870ee595dbe487c37d3950", null ],
    [ "svc", "structAV1__COMP.html#af8128359d98cbd69def126adb45965ef", null ],
    [ "compressor_stage", "structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421", null ],
    [ "last_frame_type", "structAV1__COMP.html#a0ac239b9892a1799eda25582b402430e", null ],
    [ "num_tg", "structAV1__COMP.html#a3f3c93cc1e7ce42de06a8aae22397fcf", null ],
    [ "superres_mode", "structAV1__COMP.html#a9d47cd6cfb938137c22514c510a946b5", null ],
    [ "firstpass_data", "structAV1__COMP.html#acac975b1b40d779f5475ea38b852a9f6", null ],
    [ "noise_estimate", "structAV1__COMP.html#afb2b64c6890885dbc8ebf1b1e49941e0", null ],
    [ "consec_zero_mv", "structAV1__COMP.html#a044d3dfed6b8921cd7d74dee128d987e", null ],
    [ "consec_zero_mv_alloc_size", "structAV1__COMP.html#a5d82be59e7badc649655a7f281b017c2", null ],
    [ "fp_block_size", "structAV1__COMP.html#ad2c0908b11b789a2df0a90e563a433ea", null ],
    [ "sb_counter", "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0", null ],
    [ "available_bs_size", "structAV1__COMP.html#a30c0d235c498e05247be568b93b98081", null ],
    [ "ext_part_controller", "structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86", null ],
    [ "mv_stats", "structAV1__COMP.html#aefe4d284d22f10945fe1c18cb2a095a4", null ],
    [ "ref_refresh_index", "structAV1__COMP.html#a2a58033f237baf3237ae7859e0397ad3", null ],
    [ "refresh_idx_available", "structAV1__COMP.html#a284dd9a2a0f4d09930197bc78d5c1209", null ],
    [ "ref_idx_to_skip", "structAV1__COMP.html#ac4f9451eed486d0cfb177321491e3a31", null ],
    [ "do_frame_data_update", "structAV1__COMP.html#a6e6ceda86270005d35ace1b04ec593bf", null ],
    [ "mb_weber_stats", "structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9", null ],
    [ "prep_rate_estimates", "structAV1__COMP.html#ae361e3256289fc9e62328dab440e7691", null ],
    [ "ext_rate_distribution", "structAV1__COMP.html#a01c7acc7ea64292b9563d4b8dc7d8fb3", null ],
    [ "ext_rate_scale", "structAV1__COMP.html#ae69f2f43c6b433ab69619b46f8182127", null ],
    [ "weber_bsize", "structAV1__COMP.html#ab96a678fa569c136c2ed087b68a2d401", null ],
    [ "norm_wiener_variance", "structAV1__COMP.html#aa7f83fb36f70ef378393873e41a26f7e", null ],
    [ "mb_delta_q", "structAV1__COMP.html#a063d56623dcab7e26974036303ef012e", null ],
    [ "is_dropped_frame", "structAV1__COMP.html#ad7a2fbeb7e11ff525044f82b73d1f56b", null ],
    [ "twopass_frame", "structAV1__COMP.html#afc1e293e4ae3b459e8f8d785540f6257", null ],
    [ "third_pass_ctx", "structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27", null ],
    [ "second_pass_log_stream", "structAV1__COMP.html#a3a5748228c0070093a482972587f43e5", null ],
    [ "src_sad_blk_64x64", "structAV1__COMP.html#aa6e74802d8f8aecfaa32dce27d0f0c67", null ],
    [ "rec_sse", "structAV1__COMP.html#aecdcb0ad8bfc529a749c41fc82ca5f8e", null ],
    [ "use_ducky_encode", "structAV1__COMP.html#ad36e29542fdcc0b7c2c67e142381f252", null ],
    [ "ducky_encode_info", "structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7", null ],
    [ "frames_since_last_update", "structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b", null ],
    [ "zeromv_skip_thresh_exit_part", "structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b", null ],
    [ "image_pyramid_levels", "structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e", null ],
    [ "palette_pixel_num", "structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6", null ]
];
